@@ -11,7 +11,7 @@ from .common import (
 from .config import read_xmake_config
 from .wheel import make_wheel_in, _write_wheel_file
 from .sdist import SdistBuilder
-from .__main__ import __version__
+from .templates import __version__
 
 log = logging.getLogger(__name__)
 
@@ -21,21 +21,22 @@ pyproj_toml = Path('pyproject.toml')
 
 def get_requires_for_build_sdist(config_settings=None):
     """Returns a list of requirements for building, as strings"""
-    info = read_xmake_config(pyproj_toml)
+    # info = read_xmake_config(pyproj_toml)
     # If we can get version & description from pyproject.toml (PEP 621), or
     # by parsing the module (_via_ast), we don't need any extra
     # dependencies. If not, we'll need to try importing it, so report any
     # runtime dependencies as build dependencies.
-    want_summary = 'description' in info.dynamic_metadata
-    want_version = 'version' in info.dynamic_metadata
-
-    module = Module(info.module, Path.cwd())
-    docstring, version = get_docstring_and_version_via_ast(module)
-
-    if (want_summary and not docstring) or (want_version and not version):
-        return info.metadata.get('requires_dist', [])
-    else:
-        return []
+    # want_summary = 'description' in info.dynamic_metadata
+    # want_version = 'version' in info.dynamic_metadata
+    #
+    # module = Module(info.module, Path.cwd())
+    # docstring, version = get_docstring_and_version_via_ast(module)
+    #
+    # if (want_summary and not docstring) or (want_version and not version):
+    #     return info.metadata.get('requires_dist', [])
+    # else:
+    #     return []
+    return []
 
 
 def prepare_metadata_for_build_wheel(metadata_directory, config_settings=None):
@@ -49,7 +50,7 @@ def prepare_metadata_for_build_wheel(metadata_directory, config_settings=None):
     os.mkdir(dist_info)
 
     with open(osp.join(dist_info, 'WHEEL'), 'w', encoding='utf-8') as f:
-        _write_wheel_file(f, supports_py2=metadata.supports_py2)
+        _write_wheel_file(f)
 
     with open(osp.join(dist_info, 'METADATA'), 'w', encoding='utf-8') as f:
         metadata.write_metadata_file(f)
@@ -87,7 +88,7 @@ def get_requires_for_build_wheel(
     requires = GetRequires.from_config_settings(config_settings)
 
     # These are only injected if xmake is required for the wheel step
-    xmake_requires = [*requires.xmake()]
+    xmake_requires = [*requires.get_requires()]
 
     return [
         *xmake_requires,
